====================
pyscaffoldext-django
====================

    Integration of **Django**'s built-in generator (``django-admin``)
    into **PyScaffold**


Contents
========

.. toctree::
   :maxdepth: 2

   Pyscaffold Django Extension <readme>
   Module Reference <api/modules>
   License <license>
   Authors <authors>
   Changelog <changelog>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
